﻿/* 
    Copyright (c) 2011 Microsoft Corporation.  All rights reserved.
    Use of this sample source code is subject to the terms of the Microsoft license 
    agreement under which you licensed this sample source code and is provided AS-IS.
    If you did not accept the terms of the license agreement, you are not authorized 
    to use this sample source code.  For the terms of the license, please see the 
    license agreement between you and Microsoft.
    
*/


using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using Microsoft.Devices.Sensors;
using Microsoft.Xna.Framework;

namespace RawSensorDataSample
{

    public partial class AccelerometerPage : PhoneApplicationPage
    {
        Accelerometer accelerometer;


        // Constructor
        public AccelerometerPage()
        {
            InitializeComponent();

            if (!Accelerometer.IsSupported)
            {
                // The device on which the application is running does not support
                // the accelerometer sensor. Alert the user and disable the
                // Start and Stop buttons.
                statusTextBlock.Text = "device does not support accelerometer";
                startButton.IsEnabled = false;
                stopButton.IsEnabled = false;
            }
        }

        private void startButton_Click(object sender, RoutedEventArgs e)
        {
            if (accelerometer == null)
            {
                // Instantiate the Accelerometer.
                accelerometer = new Accelerometer();
                accelerometer.TimeBetweenUpdates = TimeSpan.FromMilliseconds(20);
                accelerometer.CurrentValueChanged+=new EventHandler<SensorReadingEventArgs<AccelerometerReading>>(accelerometer_CurrentValueChanged);
            }

            try
            {
                statusTextBlock.Text = "starting accelerometer.";
                accelerometer.Start();
            }
            catch (InvalidOperationException)
            {
                statusTextBlock.Text = "unable to start accelerometer.";
            }
        }

        void accelerometer_CurrentValueChanged(object sender, SensorReadingEventArgs<AccelerometerReading> e)
        {
            // Call UpdateUI on the UI thread and pass the AccelerometerReading
            Dispatcher.BeginInvoke(() => UpdateUI(e.SensorReading));
        }

        private void UpdateUI(AccelerometerReading accelerometerReading)
        {
            statusTextBlock.Text = "getting data";

            Vector3 acceleration = accelerometerReading.Acceleration;

            // Show the numeric values
            xTextBlock.Text = "X: " + acceleration.X.ToString("0.00");
            yTextBlock.Text = "Y: " + acceleration.Y.ToString("0.00");
            zTextBlock.Text = "Z: " + acceleration.Z.ToString("0.00");

            // Show the values graphically
            xLine.X2 = xLine.X1 + acceleration.X * 200;
            yLine.Y2 = yLine.Y1 - acceleration.Y * 200;
            zLine.X2 = zLine.X1 - acceleration.Z * 100;
            zLine.Y2 = zLine.Y1 + acceleration.Z * 100;

        }

        private void stopButton_Click(object sender, RoutedEventArgs e)
        {
            if (accelerometer != null)
            {
                // Stop data acquisition from the accelerometer.
                accelerometer.Stop();
                statusTextBlock.Text = "accelerometer stopped.";
            }
        }
        
        public void pollButton_Click(object sender, RoutedEventArgs e)
        {
            if (!Accelerometer.IsSupported)
            {
                // The device on which the application is running does not support
                // the accelerometer sensor.
                statusTextBlock.Text = "device does not support accelerometer";
                return;
            }

            // If the Accelerometer object is null, initialize it.
            if (accelerometer == null)
            {
                accelerometer = new Accelerometer();
            }

            // Check to see if the Accelerometer data is valid.
            if (accelerometer.IsDataValid == false)
            {
                // If the data isn't valid, try starting the Accelerometer
                try
                {
                     
                    accelerometer.Start();

                    // Save the time that the sensor was started
                    DateTime startTime = DateTime.Now;

                    // Wait for the data to be valid.
                    while (!accelerometer.IsDataValid)
                    {
                        // If IsDataValid is false for more than 200 milliseconds,
                        // there is a problem with the sensor.
                        if ((DateTime.Now - startTime).TotalMilliseconds > 200)
                        {
                            throw new Exception();
                        }
                        System.Threading.Thread.Sleep(10);
                    }
                }
                catch (Exception)
                {
                    statusTextBlock.Text = "unable to start accelerometer.";
                }
            }

            // Update the UI with the acceleration value.
            UpdateUI(accelerometer.CurrentValue);
        }
    }
}