﻿/* 
    Copyright (c) 2011 Microsoft Corporation.  All rights reserved.
    Use of this sample source code is subject to the terms of the Microsoft license 
    agreement under which you licensed this sample source code and is provided AS-IS.
    If you did not accept the terms of the license agreement, you are not authorized 
    to use this sample source code.  For the terms of the license, please see the 
    license agreement between you and Microsoft.
    
*/


using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using Microsoft.Devices.Sensors;
using Microsoft.Xna.Framework;

namespace RawSensorDataSample
{
    public partial class CompassPage : PhoneApplicationPage
    {
        Compass compass;


        // Constructor
        public CompassPage()
        {
            InitializeComponent();

            if (!Compass.IsSupported)
            {
                // The device on which the application is running does not support
                // the compass sensor. Alert the user and disable the
                // Start and Stop buttons.
                statusTextBlock.Text = "device does not support compass";
                startButton.IsEnabled = false;
                stopButton.IsEnabled = false;
            }
        }

        private void startButton_Click(object sender, RoutedEventArgs e)
        {


            if (compass == null)
            {
                // Instantiate the Compass.
                compass = new Compass();
                compass.TimeBetweenUpdates = TimeSpan.FromMilliseconds(20);
                compass.CurrentValueChanged += new EventHandler<SensorReadingEventArgs<CompassReading>>(compass_CurrentValueChanged);
            }

            try
            {
                statusTextBlock.Text = "starting compass.";
                compass.Start();
            }
            catch (InvalidOperationException)
            {
                statusTextBlock.Text = "unable to start compass.";
            }
        }

        void compass_CurrentValueChanged(object sender, SensorReadingEventArgs<CompassReading> e)
        {
            // Call UpdateUI on the UI thread and pass the CompassReading
            Dispatcher.BeginInvoke(() => UpdateUI(e.SensorReading));
        }

        private void UpdateUI(CompassReading reading)
        {
            statusTextBlock.Text = "getting data";

            // Show the numeric values
            magneticTextBlock.Text = "MAG: " + reading.MagneticHeading.ToString("0.00");
            trueTextBlock.Text = "TRUE: " + reading.TrueHeading.ToString("0.00");

            xTextBlock.Text = "X: " + reading.MagnetometerReading.X.ToString("0.00");
            yTextBlock.Text = "Y: " + reading.MagnetometerReading.Y.ToString("0.00");
            zTextBlock.Text = "Z: " + reading.MagnetometerReading.Z.ToString("0.00");

            // Show the values graphically
            magneticLine.X2 = magneticLine.X1 - 200 * Math.Sin(MathHelper.ToRadians((float)reading.MagneticHeading));
            magneticLine.Y2 = magneticLine.Y1 - 200 * Math.Cos(MathHelper.ToRadians((float)reading.MagneticHeading));

            trueLine.X2 = trueLine.X1 - 200 * Math.Sin(MathHelper.ToRadians((float)reading.TrueHeading));
            trueLine.Y2 = trueLine.Y1 - 200 * Math.Cos(MathHelper.ToRadians((float)reading.TrueHeading));

            xLine.X2 = xLine.X1 - reading.MagnetometerReading.X * 4;
            yLine.Y2 = yLine.Y1 + reading.MagnetometerReading.Y * 4;
            zLine.X2 = zLine.X1 - reading.MagnetometerReading.Z * 4;
            zLine.Y2 = zLine.Y1 + reading.MagnetometerReading.Z * 4;

        }

        private void stopButton_Click(object sender, RoutedEventArgs e)
        {
            if (compass != null)
            {
                // Stop the data acquisition from the compass.
                compass.Stop();
                statusTextBlock.Text = "compass stopped.";
            }
        }


        void compass_Calibrate(object sender, CalibrationEventArgs e)
        {
            // perform calibration logic here.

        }
    }
}