﻿/* 
    Copyright (c) 2011 Microsoft Corporation.  All rights reserved.
    Use of this sample source code is subject to the terms of the Microsoft license 
    agreement under which you licensed this sample source code and is provided AS-IS.
    If you did not accept the terms of the license agreement, you are not authorized 
    to use this sample source code.  For the terms of the license, please see the 
    license agreement between you and Microsoft.
    
*/


using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using Microsoft.Devices.Sensors;
using Microsoft.Xna.Framework;

namespace RawSensorDataSample
{
    public partial class GyroscopePage : PhoneApplicationPage
    {
        Gyroscope gyroscope;

        // Constructor
        public GyroscopePage()
        {
            InitializeComponent();

            if (!Gyroscope.IsSupported)
            {
                // The device on which the application is running does not support
                // the gyroscope sensor. Alert the user and disable the
                // Start and Stop buttons.
                statusTextBlock.Text = "device does not support gyroscope";
                startButton.IsEnabled = false;
                stopButton.IsEnabled = false;
            }
        }

        private void startButton_Click(object sender, RoutedEventArgs e)
        {
            if (gyroscope == null)
            {
                // Instantiate the Gyroscope.
                gyroscope = new Gyroscope();
                gyroscope.TimeBetweenUpdates = TimeSpan.FromMilliseconds(20);
                gyroscope.CurrentValueChanged += new EventHandler<SensorReadingEventArgs<GyroscopeReading>>(gyroscope_CurrentValueChanged);
            }

            try
            {
                statusTextBlock.Text = "starting gyroscope.";
                gyroscope.Start();
            }
            catch (InvalidOperationException)
            {
                statusTextBlock.Text = "unable to start gyroscope.";
            }
        }

        void gyroscope_CurrentValueChanged(object sender, SensorReadingEventArgs<GyroscopeReading> e)
        {
            // Call UpdateUI on the UI thread and pass the GyroscopeReading
            Dispatcher.BeginInvoke(() => UpdateUI(e.SensorReading));
        }

        private void UpdateUI(GyroscopeReading gyroscopeReading)
        {
            statusTextBlock.Text = "getting data";

            Vector3 rotationRate = gyroscopeReading.RotationRate;

            // Show the numeric values
            xTextBlock.Text = "X: " + rotationRate.X.ToString("0.00");
            yTextBlock.Text = "Y: " + rotationRate.Y.ToString("0.00");
            zTextBlock.Text = "Z: " + rotationRate.Z.ToString("0.00");

            // Show the values graphically
            xLine.X2 = xLine.X1 + rotationRate.X * 200;
            yLine.Y2 = yLine.Y1 - rotationRate.Y * 200;
            zLine.X2 = zLine.X1 - rotationRate.Z * 100;
            zLine.Y2 = zLine.Y1 + rotationRate.Z * 100;

        }

        private void stopButton_Click(object sender, RoutedEventArgs e)
        {
            if (gyroscope != null)
            {
                // Stop data acquisition from the accelerometer.
                gyroscope.Stop();
                statusTextBlock.Text = "gyroscope stopped.";
            }
        }
    }
}